package de.intevation.gnv.state;

import de.intevation.artifacts.CallContext;

import de.intevation.gnv.state.exception.StateException;

import java.io.OutputStream;

import java.util.Collection;

import org.w3c.dom.Document;

/**
 * This is the interface description of an output state. Currently, there are
 * two methods defined:<br>
 * <ol>
 *  <li>out(): To start an output of the current state.</li>
 *  <li>getOutputModes(): To retrieve a list of possible output modes.</li>
 * </ol>
 *
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 */
public interface OutputState
extends          State
{

    /**
     * Returns the Rendered Result of an State.
     *
     * @param format
     * @param inputData
     * @param outputStream
     * @param uuid
     * @param callContext
     * @throws StateException
     */
    public void out(
        Document              format,
        Collection<InputData> inputData,
        OutputStream          outputStream,
        String                uuid,
        CallContext           callContext
    ) throws StateException;

    /**
     * Delivers the provided OutputModes of an State
     *
     * @return the provided OutputModes of an State
     */
    public Collection<OutputMode> getOutputModes();
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :